@@ -1,9 +1,9 @@
 gaussianfit <- function(x, y) {
-    lassofit <- glmnet(x = x, y = y, alpha = 1, maxit = 1e+06)
+    lassofit <- glmnet(x = x, y = y, family = "gaussian", alpha = 1, maxit = 1e+06)
     scadfit <- ncvreg(X = x, y = y, family = "gaussian", penalty = "SCAD", 
-        max.iter = 1e+06)
+        warn = FALSE, max.iter = 1e+04)
     mcpfit <- ncvreg(X = x, y = y, family = "gaussian", penalty = "MCP", 
-        max.iter = 1e+06)
+        warn = FALSE, max.iter = 1e+04)
     lasso.path <- as.matrix(lassofit$beta)
     scad.path <- as.matrix(scadfit$beta[-1, ])
     mcp.path <- as.matrix(mcpfit$beta[-1, ])
